
use strict;
use Grid::GPT::Setup;
use Globus::Core::Paths;
use Getopt::Long;

# Set up a particular scheduler for use with the MJS

# default values of config parameters
my $gt4_location        = $ENV{GLOBUS_LOCATION};
my $mjfs_manager_type   = 'Fork';
my $package_name        = '';
my $scratch_directory   = '';
my $substitution_definitions_file = '';
my $substitution_definitions_refresh_period = '480';
my $enable_default_software_environment = 0;
my $help = 0;
my $java_ok = 0;
my $rc = 0;

GetOptions('type|m=s' => \$mjfs_manager_type,
           'package-name|p=s' => \$package_name,
           'scratch-directory|s=s' => \$scratch_directory,
           'substitution-definitions-file|f=s' => \$substitution_definitions_file,
           'substitution-definitions-refresh-period|r=s' => \$substitution_definitions_refresh_period,
           'enable-default-software-environment|e' => \$enable_default_software_environment,
           'help|h' => \$help);

&usage if ($help || $package_name eq '');

#Check for java in the PATH
foreach (split(/:/, $ENV{PATH})) {
    if (-x "$_/java") {
        $java_ok = 1;
        last
    }
}

if ($java_ok == 0) {

    # if JAVA_HOME is found, then use it in the PATH so java commands run
    if (exists $ENV{JAVA_HOME}) {
        $ENV{'PATH'} = "$ENV{'PATH'}:$ENV{'JAVA_HOME'}/bin";
    } else {
        print STDERR "Unable to locate java executable in PATH\n";
        exit 1;
    }
}

if ($substitution_definitions_file eq '')
{
    $substitution_definitions_file
        = "$gt4_location/etc/gram-service-$mjfs_manager_type/"
        . "substitution-definition.properties";
}

my $metadata =
    new Grid::GPT::Setup(package_name => $package_name);
my $globusdir = $ENV{GLOBUS_LOCATION};
my $jndi_dir = "$ENV{GLOBUS_LOCATION}/etc/gram-service-$mjfs_manager_type";
my $jndi_template = $ENV{GLOBUS_LOCATION} .
        '/setup/globus/gram-manager-deploy-jndi-config.xml.in';
my $jndi_file = "$jndi_dir/jndi-config.xml";
my $subdef_template = $ENV{GLOBUS_LOCATION} .
        '/setup/globus/substitution-definition.properties.in';
my $subdef_file = "$jndi_dir/substitution-definition.properties";

local(*JNDI_TEMPLATE);
local(*JNDI_FILE);
local(*SUBDEF_TEMPLATE);
local(*SUBDEF_FILE);

mkdir($jndi_dir, 0755)
    || -d $jndi_dir
    || die "Unable to create JNDI dir $jndi_dir\n";

open(JNDI_TEMPLATE, "<$jndi_template") || die "Unable to open JDNI template $jndi_template\n";
open(JNDI_FILE, ">$jndi_file") || die "Unable to open JNDI output file $jndi_file\n";

while(<JNDI_TEMPLATE>) {
    s/\@LOCAL_RESOURCE_MANAGER_NAME\@/$mjfs_manager_type/g;
    if ($scratch_directory ne '') {
        s/\@SCRATCH_DIR_BEGIN_COMMENT\@//g;
        s/\@SCRATCH_DIRECTORY\@/$scratch_directory/g;
        s/\@SCRATCH_DIR_END_COMMENT\@//g;
    } else {
        s|\@SCRATCH_DIR_BEGIN_COMMENT\@|<!-- Site-specific scratchDir\nDefault: \${GLOBUS_USER_HOME}/.globus/scratch|g;
        s|\@SCRATCH_DIRECTORY\@|\$\{GLOBUS_USER_HOME\}/.globus/scratch|g;
        s/\@SCRATCH_DIR_END_COMMENT\@/-->/g;
    }
    s/\@SUBSTITUTION_DEFINITIONS_FILE\@/$substitution_definitions_file/g;
    s/\@SUBSTITUTION_DEFINITIONS_REFRESH_PERIOD\@/$substitution_definitions_refresh_period/g;
    if ($enable_default_software_environment)
    {
        s/\@ENABLE_DEFAULT_SOFTWARE_ENVIRONMENT\@/true/g;
    }
    else
    {
        s/\@ENABLE_DEFAULT_SOFTWARE_ENVIRONMENT\@/false/g;
    }
    print JNDI_FILE $_;
}

close(JNDI_TEMPLATE);
close(JNDI_FILE);

open(SUBDEF_TEMPLATE, "<$subdef_template") || die "Unable to open substitution definitions template $subdef_template\n";
open(SUBDEF_FILE, ">$subdef_file") || die "Unable to open substitution definitions output file $subdef_file\n";

while(<SUBDEF_TEMPLATE>) {
    s/\@GLOBUS_LOCATION\@/$globusdir/g;
    print SUBDEF_FILE $_;
}

close(SUBDEF_TEMPLATE);
close(SUBDEF_FILE);

$rc = system(". $ENV{GLOBUS_LOCATION}/etc/globus-devel-env.sh && java org.globus.exec.service.exec.utils.FileMappingConfig -scheduler $mjfs_manager_type");
if($? == 0)
{
    $metadata->finish();
}
else
{
    print STDERR "Error creating GRAM configuration.\n";
}

sub usage
{
    print "Usage: $0 [-m <manager type>] [-s <scratch dir>]\n".
      "              [-a <LRM adapter class>] [-f <sub def file>]\n".
      "              [-r <sub def refresh period>] [-e] -p <package>\n".
	  "           $0  --help|-help|-h\n";
    exit 1;
}


